Trims whitespace, drops NA and empty strings, then returns the number of
distinct remaining values.
See also
Other helpers:
.add_year(),
.as_event01(),
.as_yesno(),
.find_col(),
.first_nonempty_col(),
.safe_date()
Trims whitespace, drops NA and empty strings, then returns the number of
distinct remaining values.
Other helpers:
.add_year(),
.as_event01(),
.as_yesno(),
.find_col(),
.first_nonempty_col(),
.safe_date()