Derives the treatment year from the first available date column among
erstvorstellung, erstdiagnose, therapie_beginn, tumorkonferenz_datum,
last_follow_up. If none of these exist, the column is filled with NA.
Details
If multiple matching columns exist (e.g. duplicate erstdiagnose columns
that janitor::clean_names() renames to erstdiagnose and
erstdiagnose_2), the first matching column wins.
See also
Other helpers:
.as_event01(),
.as_yesno(),
.find_col(),
.first_nonempty_col(),
.n_distinct_nonempty(),
.safe_date()